@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2024 Taler Systems SA
+  Copyright (C) 2024, 2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -424,7 +424,6 @@ deposit_get_cb (
   case MHD_HTTP_OK:
     {
       enum GNUNET_DB_QueryStatus qs;
-      bool cleared = false;
 
       GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                   "Exchange returned wire transfer over %s for deposited coin %s\n",
@@ -433,25 +432,10 @@ deposit_get_cb (
       qs = db_plugin->insert_deposit_to_transfer (
         db_plugin->cls,
         w->deposit_serial,
-        &dr->details.ok,
-        &cleared);
-      if (qs < 0)
-      {
-        GNUNET_break (0);
-        GNUNET_SCHEDULER_shutdown ();
-        return;
-      }
-      if (! cleared)
-      {
-        qs = db_plugin->update_deposit_confirmation_status (
-          db_plugin->cls,
-          w->deposit_serial,
-          true, /* this failed, wire_pending remains true */
-          GNUNET_TIME_absolute_to_timestamp (future_retry),
-          w->retry_backoff,
-          "wire transfer unknown");
-      }
-      if (qs < 0)
+        &w->h_wire,
+        exchange_url,
+        &dr->details.ok);
+      if (qs <= 0)
       {
         GNUNET_break (0);
         GNUNET_SCHEDULER_shutdown ();
@@ -493,9 +477,10 @@ deposit_get_cb (
         qs = db_plugin->update_deposit_confirmation_status (
           db_plugin->cls,
           w->deposit_serial,
-          true, /* wire_pending is still true! */
+          true, /* need to try again in the future! */
           GNUNET_TIME_absolute_to_timestamp (future_retry),
-          w->retry_backoff,
+          MHD_HTTP_ACCEPTED,
+          TALER_EC_NONE,
           "Exchange reported 202 Accepted but no KYC block");
         if (qs < 0)
         {
@@ -517,9 +502,10 @@ deposit_get_cb (
         qs = db_plugin->update_deposit_confirmation_status (
           db_plugin->cls,
           w->deposit_serial,
-          true,
+          true /* need to try again in the future */,
           GNUNET_TIME_absolute_to_timestamp (future_retry),
-          w->retry_backoff,
+          MHD_HTTP_ACCEPTED,
+          TALER_EC_NONE,
           "Exchange reported 202 Accepted due to KYC/AML block");
         if (qs < 0)
         {
@@ -533,32 +519,50 @@ deposit_get_cb (
   default:
     {
       enum GNUNET_DB_QueryStatus qs;
-      char *msg;
+      bool retry_needed = false;
 
       GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Exchange %s returned tracking failure for deposited coin %s\n",
+                  "Exchange %s returned tracking failure for deposited coin %s: %u\n",
                   exchange_url,
-                  TALER_B2S (&w->coin_pub));
-      GNUNET_asprintf (&msg,
-                       "Unexpected exchange status %u (#%d, %s)\n",
-                       dr->hr.http_status,
-                       (int) dr->hr.ec,
-                       dr->hr.hint);
+                  TALER_B2S (&w->coin_pub),
+                  dr->hr.http_status);
+      /* rough classification by HTTP status group */
+      switch (dr->hr.http_status / 100)
+      {
+      case 0:
+        /* timeout */
+        retry_needed = true;
+        break;
+      case 1:
+      case 2:
+      case 3:
+        /* very strange */
+        retry_needed = false;
+        break;
+      case 4:
+        /* likely fatal */
+        retry_needed = false;
+        break;
+      case 5:
+        /* likely transient */
+        retry_needed = true;
+        break;
+      }
       qs = db_plugin->update_deposit_confirmation_status (
         db_plugin->cls,
         w->deposit_serial,
-        true, /* this failed, wire_pending remains true */
+        retry_needed,
         GNUNET_TIME_absolute_to_timestamp (future_retry),
-        w->retry_backoff,
-        msg);
-      GNUNET_free (msg);
+        (uint32_t) dr->hr.http_status,
+        dr->hr.ec,
+        dr->hr.hint);
       if (qs < 0)
       {
         GNUNET_break (0);
         GNUNET_SCHEDULER_shutdown ();
         return;
       }
-      return;
+      break;
     }
   } /* end switch */
 
@@ -569,9 +573,14 @@ deposit_get_cb (
   GNUNET_free (w->instance_id);
   GNUNET_free (w);
   GNUNET_assert (NULL != keys);
-  if ( (w_count < CONCURRENCY_LIMIT / 2) ||
-       (0 == w_count) )
+  if (0 == w_count)
   {
+    /* We only SELECT() again after having finished
+       all requests, as otherwise we'll most like
+       just SELECT() those again that are already
+       being requested; alternatively, we could
+       update the retry_time already on SELECT(),
+       but this should be easier on the DB. */
     if (NULL != task)
       GNUNET_SCHEDULER_cancel (task);
     task = GNUNET_SCHEDULER_add_now (&select_work,
@@ -586,11 +595,12 @@ deposit_get_cb (
  * @param cls NULL
  * @param deposit_serial identifies the deposit operation
  * @param wire_deadline when is the wire due
- * @param retry_backoff current value for the retry backoff
+ * @param retry_time current value for the retry backoff
  * @param h_contract_terms hash of the contract terms
  * @param merchant_priv private key of the merchant
  * @param instance_id row ID of the instance
- * @param h_wire hash of the merchant's wire account into  * @param amount_with_fee amount the exchange will deposit for this coin
+ * @param h_wire hash of the merchant's wire account into
+ * @param amount_with_fee amount the exchange will deposit for this coin
  * @param deposit_fee fee the exchange will charge for this coin which the deposit was made
  * @param coin_pub public key of the deposited coin
  */
@@ -599,7 +609,7 @@ pending_deposits_cb (
   void *cls,
   uint64_t deposit_serial,
   struct GNUNET_TIME_Absolute wire_deadline,
-  struct GNUNET_TIME_Relative retry_backoff,
+  struct GNUNET_TIME_Absolute retry_time,
   const struct TALER_PrivateContractHashP *h_contract_terms,
   const struct TALER_MerchantPrivateKeyP *merchant_priv,
   const char *instance_id,
@@ -609,20 +619,30 @@ pending_deposits_cb (
   const struct TALER_CoinSpendPublicKeyP *coin_pub)
 {
   struct ExchangeInteraction *w;
+  struct GNUNET_TIME_Absolute mx
+    = GNUNET_TIME_absolute_max (wire_deadline,
+                                retry_time);
+  struct GNUNET_TIME_Relative retry_backoff;
 
   (void) cls;
-  if (GNUNET_TIME_absolute_is_future (wire_deadline))
+  if (GNUNET_TIME_absolute_is_future (mx))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Pending deposit has deadline in the future at %s\n",
-                GNUNET_TIME_absolute2s (wire_deadline));
-    run_at (wire_deadline);
+                "Pending deposit should be checked next at %s\n",
+                GNUNET_TIME_absolute2s (mx));
+    run_at (mx);
     return;
   }
+  if (GNUNET_TIME_absolute_is_zero (retry_time))
+    retry_backoff = GNUNET_TIME_absolute_get_duration (wire_deadline);
+  else
+    retry_backoff = GNUNET_TIME_absolute_get_difference (wire_deadline,
+                                                         retry_time);
   w = GNUNET_new (struct ExchangeInteraction);
   w->deposit_serial = deposit_serial;
   w->wire_deadline = wire_deadline;
-  w->retry_backoff = GNUNET_TIME_STD_BACKOFF (retry_backoff);
+  w->retry_backoff = GNUNET_TIME_randomized_backoff (retry_backoff,
+                                                     GNUNET_TIME_UNIT_DAYS);
   w->h_contract_terms = *h_contract_terms;
   w->merchant_priv = *merchant_priv;
   w->h_wire = *h_wire;
@@ -766,6 +786,14 @@ select_work (void *cls)
 static struct GNUNET_OS_Process *
 start_worker (const char *base_url)
 {
+  char toff[30];
+  long long zo;
+
+  zo = GNUNET_TIME_get_offset ();
+  GNUNET_snprintf (toff,
+                   sizeof (toff),
+                   "%lld",
+                   zo);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Launching worker for exchange `%s' using `%s`\n",
               base_url,
@@ -782,6 +810,7 @@ start_worker (const char *base_url)
       "taler-merchant-depositcheck",
       "-e", base_url,
       "-L", "INFO",
+      "-T", toff,
       test_mode ? "-t" : NULL,
       NULL);
   return GNUNET_OS_start_process (
@@ -794,6 +823,7 @@ start_worker (const char *base_url)
     "-c", cfg_filename,
     "-e", base_url,
     "-L", "INFO",
+    "-T", toff,
     test_mode ? "-t" : NULL,
     NULL);
 }
@@ -823,6 +853,8 @@ child_done_cb (void *cls,
   struct Child *c = cls;
 
   c->cwh = NULL;
+  GNUNET_OS_process_destroy (c->process);
+  c->process = NULL;
   if ( (GNUNET_OS_PROCESS_EXITED != type) ||
        (0 != exit_code) )
   {
@@ -835,8 +867,6 @@ child_done_cb (void *cls,
     global_ret = EXIT_NOTINSTALLED;
     return;
   }
-  GNUNET_OS_process_destroy (c->process);
-  c->process = NULL;
   if (test_mode &&
       (! GNUNET_TIME_relative_is_zero (c->rd)) )
   {
