@@ -33,9 +33,10 @@
  * @return MHD result code
  */
 MHD_RESULT
-TMH_private_get_templates_ID (const struct TMH_RequestHandler *rh,
-                              struct MHD_Connection *connection,
-                              struct TMH_HandlerContext *hc);
+TMH_private_get_templates_ID (
+  const struct TMH_RequestHandler *rh,
+  struct MHD_Connection *connection,
+  struct TMH_HandlerContext *hc);
 
 /* end of taler-merchant-httpd_private-get-templates-ID.h */
 #endif
