@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2023 Taler Systems SA
+  (C) 2023, 2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -54,11 +54,11 @@ TMH_private_get_tokenfamilies_SLUG (const struct TMH_RequestHandler *rh,
                                        TALER_EC_GENERIC_DB_FETCH_FAILED,
                                        "lookup_token_family");
   }
-  if (0 == status)
+  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == status)
   {
     return TALER_MHD_reply_with_error (connection,
                                        MHD_HTTP_NOT_FOUND,
-                                       TALER_EC_MERCHANT_GENERIC_PRODUCT_UNKNOWN,
+                                       TALER_EC_MERCHANT_GENERIC_TOKEN_FAMILY_UNKNOWN,
                                        hc->infix);
   }
   {
@@ -85,25 +85,42 @@ TMH_private_get_tokenfamilies_SLUG (const struct TMH_RequestHandler *rh,
     result = TALER_MHD_REPLY_JSON_PACK (
       connection,
       MHD_HTTP_OK,
-      GNUNET_JSON_pack_string ("slug", details.slug),
-      GNUNET_JSON_pack_string ("name", details.name),
-      GNUNET_JSON_pack_string ("description", details.description),
+      GNUNET_JSON_pack_string ("slug",
+                               details.slug),
+      GNUNET_JSON_pack_string ("name",
+                               details.name),
+      GNUNET_JSON_pack_string ("description",
+                               details.description),
       GNUNET_JSON_pack_object_steal ("description_i18n",
                                      details.description_i18n),
-      GNUNET_JSON_pack_timestamp ("valid_after", details.valid_after),
-      GNUNET_JSON_pack_timestamp ("valid_before", details.valid_before),
-      GNUNET_JSON_pack_time_rel ("duration", details.duration),
-      GNUNET_JSON_pack_string ("kind", kind),
-      GNUNET_JSON_pack_int64 ("issued", details.issued),
-      GNUNET_JSON_pack_int64 ("used", details.used)
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_object_steal ("extra_data",
+                                       details.extra_data)),
+      GNUNET_JSON_pack_timestamp ("valid_after",
+                                  details.valid_after),
+      GNUNET_JSON_pack_timestamp ("valid_before",
+                                  details.valid_before),
+      GNUNET_JSON_pack_time_rel ("duration",
+                                 details.duration),
+      GNUNET_JSON_pack_time_rel ("validity_granularity",
+                                 details.validity_granularity),
+      GNUNET_JSON_pack_time_rel ("start_offset",
+                                 details.start_offset),
+      GNUNET_JSON_pack_string ("kind",
+                               kind),
+      GNUNET_JSON_pack_int64 ("issued",
+                              details.issued),
+      GNUNET_JSON_pack_int64 ("used",
+                              details.used)
       );
 
     GNUNET_free (details.name);
     GNUNET_free (details.description);
+    GNUNET_free (details.cipher_spec);
     GNUNET_free (kind);
     return result;
   }
 }
 
 
-/* end of taler-merchant-httpd_private-get-products-SLUG.c */
+/* end of taler-merchant-httpd_private-get-token-families-SLUG.c */
