@@ -28,6 +28,8 @@
 #include "taler_merchant_bank_lib.h"
 #include <taler/taler_dbevents.h>
 #include <taler/taler_json_lib.h>
+#include "taler-merchant-httpd_mfa.h"
+#include <regex.h>
 
 
 MHD_RESULT
@@ -83,6 +85,53 @@ TMH_private_post_account (const struct TMH_RequestHandler *rh,
       return mret;
     }
   }
+  {
+    char *apt = GNUNET_strdup (TMH_allowed_payment_targets);
+    char *method = TALER_payto_get_method (uri.full_payto);
+    bool ok;
+
+    ok = false;
+    for (const char *tok = strtok (apt,
+                                   " ");
+         NULL != tok;
+         tok = strtok (NULL,
+                       " "))
+    {
+      if (0 == strcmp ("*",
+                       tok))
+        ok = true;
+      if (0 == strcmp (method,
+                       tok))
+        ok = true;
+      if (ok)
+        break;
+    }
+    GNUNET_free (method);
+    GNUNET_free (apt);
+    if (! ok)
+    {
+      GNUNET_break_op (0);
+      return TALER_MHD_reply_with_error (connection,
+                                         MHD_HTTP_BAD_REQUEST,
+                                         TALER_EC_GENERIC_PAYTO_URI_MALFORMED,
+                                         "The payment target type is forbidden by policy");
+    }
+  }
+
+  if ( (NULL != TMH_payment_target_regex) &&
+       (0 !=
+        regexec (&TMH_payment_target_re,
+                 uri.full_payto,
+                 0,
+                 NULL,
+                 0)) )
+  {
+    GNUNET_break_op (0);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PAYTO_URI_MALFORMED,
+                                       "The specific account is forbidden by policy");
+  }
 
   if ( (NULL == credit_facade_url) !=
        (NULL == credit_facade_credentials) )
@@ -114,6 +163,44 @@ TMH_private_post_account (const struct TMH_RequestHandler *rh,
     TALER_MERCHANT_BANK_auth_free (&auth);
   }
 
+  /* FIXME: might want to do all of the DB interactions below in one transaction... */
+  {
+    enum GNUNET_DB_QueryStatus qs;
+    enum GNUNET_GenericReturnValue ret;
+
+    qs = TMH_db->select_accounts (TMH_db->cls,
+                                  mi->settings.id,
+                                  NULL,
+                                  NULL);
+    switch (qs)
+    {
+    case GNUNET_DB_STATUS_SOFT_ERROR:
+    case GNUNET_DB_STATUS_HARD_ERROR:
+      GNUNET_break (0);
+      return TALER_MHD_reply_with_error (connection,
+                                         MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                         TALER_EC_GENERIC_DB_FETCH_FAILED,
+                                         "select_accounts");
+    case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+      /* skip MFA */
+      break;
+    case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+      ret = TMH_mfa_check_simple (hc,
+                                  TALER_MERCHANT_MFA_CO_ACCOUNT_CONFIGURATION,
+                                  mi);
+
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Account creation MFA check returned %d\n",
+                  (int) ret);
+      if (GNUNET_OK != ret)
+      {
+        return (GNUNET_NO == ret)
+        ? MHD_YES
+        : MHD_NO;
+      }
+    }
+  }
+
   /* convert provided payto URI into internal data structure with salts */
   wm = TMH_setup_wire_account (uri,
                                credit_facade_url,
