@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2020-2023 Taler Systems SA
+  (C) 2020-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as
@@ -25,6 +25,8 @@
 #include "platform.h"
 #include "taler-merchant-httpd_private-post-instances.h"
 #include "taler-merchant-httpd_helper.h"
+#include "taler-merchant-httpd.h"
+#include "taler-merchant-httpd_mfa.h"
 #include "taler_merchant_bank_lib.h"
 #include <taler/taler_dbevents.h>
 #include <taler/taler_json_lib.h>
@@ -42,33 +44,42 @@
  * @param rh context of the handler
  * @param connection the MHD connection to handle
  * @param[in,out] hc context with further information about the request
+ * @param login_token_expiration set to how long a login token validity
+ *   should be, use zero if no login token should be created
+ * @param validation_needed true if self-provisioned and
+ *   email/phone registration is required before the
+ *   instance can become fully active
  * @return MHD result code
  */
-MHD_RESULT
-TMH_private_post_instances (const struct TMH_RequestHandler *rh,
-                            struct MHD_Connection *connection,
-                            struct TMH_HandlerContext *hc)
+static MHD_RESULT
+post_instances (const struct TMH_RequestHandler *rh,
+                struct MHD_Connection *connection,
+                struct TMH_HandlerContext *hc,
+                struct GNUNET_TIME_Relative login_token_expiration,
+                bool validation_needed)
 {
   struct TALER_MERCHANTDB_InstanceSettings is = { 0 };
   struct TALER_MERCHANTDB_InstanceAuthSettings ias;
-  const char *auth_token = NULL;
-  const char *uts = "business";
+  const char *auth_password = NULL;
   struct TMH_WireMethod *wm_head = NULL;
   struct TMH_WireMethod *wm_tail = NULL;
   const json_t *jauth;
+  bool no_transfer_delay;
+  bool no_pay_delay;
+  bool no_refund_delay;
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_string ("id",
                              (const char **) &is.id),
     GNUNET_JSON_spec_string ("name",
                              (const char **) &is.name),
-    GNUNET_JSON_spec_mark_optional (
-      GNUNET_JSON_spec_string ("user_type",
-                               &uts),
-      NULL),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_string ("email",
                                (const char **) &is.email),
       NULL),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_string ("phone_number",
+                               (const char **) &is.phone),
+      NULL),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_string ("website",
                                (const char **) &is.website),
@@ -85,10 +96,18 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                            &is.jurisdiction),
     GNUNET_JSON_spec_bool ("use_stefan",
                            &is.use_stefan),
-    GNUNET_JSON_spec_relative_time ("default_wire_transfer_delay",
-                                    &is.default_wire_transfer_delay),
-    GNUNET_JSON_spec_relative_time ("default_pay_delay",
-                                    &is.default_pay_delay),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_relative_time ("default_wire_transfer_delay",
+                                      &is.default_wire_transfer_delay),
+      &no_transfer_delay),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_relative_time ("default_pay_delay",
+                                      &is.default_pay_delay),
+      &no_pay_delay),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_relative_time ("default_refund_delay",
+                                      &is.default_refund_delay),
+      &no_refund_delay),
     GNUNET_JSON_spec_end ()
   };
 
@@ -103,12 +122,18 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
              ? MHD_YES
              : MHD_NO;
   }
+  if (no_transfer_delay)
+    is.default_wire_transfer_delay = TMH_default_wire_transfer_delay;
+  if (no_pay_delay)
+    is.default_pay_delay = TMH_default_pay_delay;
+  if (no_refund_delay)
+    is.default_refund_delay = TMH_default_refund_delay;
   {
     enum GNUNET_GenericReturnValue ret;
 
     ret = TMH_check_auth_config (connection,
                                  jauth,
-                                 &auth_token);
+                                 &auth_password);
     if (GNUNET_OK != ret)
     {
       GNUNET_JSON_parse_free (spec);
@@ -208,12 +233,12 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
             (NULL != is.logo && NULL != mi->settings.logo &&
              0 == strcmp (mi->settings.logo,
                           is.logo))) &&
-           ( ( (NULL != auth_token) &&
+           ( ( (NULL != auth_password) &&
                (GNUNET_OK ==
-                TMH_check_auth (auth_token,
+                TMH_check_auth (auth_password,
                                 &mi->auth.auth_salt,
                                 &mi->auth.auth_hash)) ) ||
-             ( (NULL == auth_token) &&
+             ( (NULL == auth_password) &&
                (GNUNET_YES ==
                 GNUNET_is_zero (&mi->auth.auth_hash))) ) &&
            (1 == json_equal (mi->settings.address,
@@ -226,7 +251,10 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                                       is.default_wire_transfer_delay)) &&
            (GNUNET_TIME_relative_cmp (mi->settings.default_pay_delay,
                                       ==,
-                                      is.default_pay_delay)) )
+                                      is.default_pay_delay)) &&
+           (GNUNET_TIME_relative_cmp (mi->settings.default_refund_delay,
+                                      ==,
+                                      is.default_refund_delay)) )
       {
         GNUNET_JSON_parse_free (spec);
         return TALER_MHD_reply_static (connection,
@@ -243,8 +271,80 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
     }
   }
 
+  /* Check MFA is satisfied */
+  if (validation_needed)
+  {
+    enum GNUNET_GenericReturnValue ret = GNUNET_SYSERR;
+
+    if ( (0 != (TEH_TCS_SMS & TEH_mandatory_tan_channels)) &&
+         (NULL == is.phone) )
+    {
+      GNUNET_break_op (0);
+      GNUNET_JSON_parse_free (spec);
+      return TALER_MHD_reply_with_error (connection,
+                                         MHD_HTTP_BAD_REQUEST,
+                                         TALER_EC_GENERIC_PARAMETER_MISSING,
+                                         "phone_number");
+
+    }
+    if ( (0 != (TEH_TCS_EMAIL & TEH_mandatory_tan_channels)) &&
+         (NULL == is.email) )
+    {
+      GNUNET_break_op (0);
+      GNUNET_JSON_parse_free (spec);
+      return TALER_MHD_reply_with_error (connection,
+                                         MHD_HTTP_BAD_REQUEST,
+                                         TALER_EC_GENERIC_PARAMETER_MISSING,
+                                         "email");
+    }
+    switch (TEH_mandatory_tan_channels)
+    {
+    case TEH_TCS_NONE:
+      GNUNET_assert (0);
+      ret = GNUNET_OK;
+      break;
+    case TEH_TCS_SMS:
+      is.phone_validated = true;
+      ret = TMH_mfa_challenges_do (hc,
+                                   TALER_MERCHANT_MFA_CO_INSTANCE_PROVISION,
+                                   true,
+                                   TALER_MERCHANT_MFA_CHANNEL_SMS,
+                                   is.phone,
+                                   TALER_MERCHANT_MFA_CHANNEL_NONE);
+      break;
+    case TEH_TCS_EMAIL:
+      is.email_validated = true;
+      ret = TMH_mfa_challenges_do (hc,
+                                   TALER_MERCHANT_MFA_CO_INSTANCE_PROVISION,
+                                   true,
+                                   TALER_MERCHANT_MFA_CHANNEL_EMAIL,
+                                   is.email,
+                                   TALER_MERCHANT_MFA_CHANNEL_NONE);
+      break;
+    case TEH_TCS_EMAIL_AND_SMS:
+      is.phone_validated = true;
+      is.email_validated = true;
+      ret = TMH_mfa_challenges_do (hc,
+                                   TALER_MERCHANT_MFA_CO_INSTANCE_PROVISION,
+                                   true,
+                                   TALER_MERCHANT_MFA_CHANNEL_SMS,
+                                   is.phone,
+                                   TALER_MERCHANT_MFA_CHANNEL_EMAIL,
+                                   is.email,
+                                   TALER_MERCHANT_MFA_CHANNEL_NONE);
+      break;
+    }
+    if (GNUNET_OK != ret)
+    {
+      GNUNET_JSON_parse_free (spec);
+      return (GNUNET_NO == ret)
+        ? MHD_YES
+        : MHD_NO;
+    }
+  }
+
   /* handle authentication token setup */
-  if (NULL == auth_token)
+  if (NULL == auth_password)
   {
     memset (&ias.auth_salt,
             0,
@@ -256,7 +356,7 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
   else
   {
     /* Sets 'auth_salt' and 'auth_hash' */
-    TMH_compute_auth (auth_token,
+    TMH_compute_auth (auth_password,
                       &ias.auth_salt,
                       &ias.auth_hash);
   }
@@ -276,11 +376,14 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
     mi->settings.name = GNUNET_strdup (is.name);
     if (NULL != is.email)
       mi->settings.email = GNUNET_strdup (is.email);
+    if (NULL != is.phone)
+      mi->settings.phone = GNUNET_strdup (is.phone);
     if (NULL != is.website)
       mi->settings.website = GNUNET_strdup (is.website);
     if (NULL != is.logo)
       mi->settings.logo = GNUNET_strdup (is.logo);
     mi->auth = ias;
+    mi->validation_needed = validation_needed;
     GNUNET_CRYPTO_eddsa_key_create (&mi->merchant_priv.eddsa_priv);
     GNUNET_CRYPTO_eddsa_key_get_public (&mi->merchant_priv.eddsa_priv,
                                         &mi->merchant_pub.eddsa_pub);
@@ -303,7 +406,8 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                                     &mi->merchant_pub,
                                     &mi->merchant_priv,
                                     &mi->settings,
-                                    &mi->auth);
+                                    &mi->auth,
+                                    validation_needed);
       switch (qs)
       {
       case GNUNET_DB_STATUS_HARD_ERROR:
@@ -364,19 +468,136 @@ retry:
                    TMH_add_instance (mi));
     TMH_reload_instances (mi->settings.id);
   }
-  if (0 == strcmp (is.id,
-                   "admin"))
+  GNUNET_JSON_parse_free (spec);
+  if (GNUNET_TIME_relative_is_zero (login_token_expiration))
   {
-    GNUNET_free (TMH_default_auth); /* clear it if the default instance was
-                                       created */
+    return TALER_MHD_reply_static (connection,
+                                   MHD_HTTP_NO_CONTENT,
+                                   NULL,
+                                   NULL,
+                                   0);
   }
 
-  GNUNET_JSON_parse_free (spec);
-  return TALER_MHD_reply_static (connection,
-                                 MHD_HTTP_NO_CONTENT,
-                                 NULL,
-                                 NULL,
-                                 0);
+  {
+    struct TALER_MERCHANTDB_LoginTokenP btoken;
+    enum TMH_AuthScope iscope = TMH_AS_REFRESHABLE | TMH_AS_SPA;
+    enum GNUNET_DB_QueryStatus qs;
+    struct GNUNET_TIME_Timestamp expiration_time;
+    bool refreshable = true;
+
+    GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_NONCE,
+                                &btoken,
+                                sizeof (btoken));
+    expiration_time
+      = GNUNET_TIME_relative_to_timestamp (login_token_expiration);
+    qs = TMH_db->insert_login_token (TMH_db->cls,
+                                     is.id,
+                                     &btoken,
+                                     GNUNET_TIME_timestamp_get (),
+                                     expiration_time,
+                                     iscope,
+                                     "login token from instance creation");
+    switch (qs)
+    {
+    case GNUNET_DB_STATUS_HARD_ERROR:
+    case GNUNET_DB_STATUS_SOFT_ERROR:
+    case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+      GNUNET_break (0);
+      return TALER_MHD_reply_with_ec (connection,
+                                      TALER_EC_GENERIC_DB_STORE_FAILED,
+                                      "insert_login_token");
+    case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+      break;
+    }
+
+    {
+      char *tok;
+      MHD_RESULT ret;
+      char *val;
+
+      val = GNUNET_STRINGS_data_to_string_alloc (&btoken,
+                                                 sizeof (btoken));
+      GNUNET_asprintf (&tok,
+                       RFC_8959_PREFIX "%s",
+                       val);
+      GNUNET_free (val);
+      ret = TALER_MHD_REPLY_JSON_PACK (
+        connection,
+        MHD_HTTP_OK,
+        GNUNET_JSON_pack_string ("access_token",
+                                 tok),
+        GNUNET_JSON_pack_string ("token",
+                                 tok),
+        GNUNET_JSON_pack_string ("scope",
+                                 TMH_get_name_by_scope (iscope,
+                                                        &refreshable)),
+        GNUNET_JSON_pack_bool ("refreshable",
+                               refreshable),
+        GNUNET_JSON_pack_timestamp ("expiration",
+                                    expiration_time));
+      GNUNET_free (tok);
+      return ret;
+    }
+  }
+}
+
+
+/**
+ * Generate an instance, given its configuration.
+ *
+ * @param rh context of the handler
+ * @param connection the MHD connection to handle
+ * @param[in,out] hc context with further information about the request
+ * @return MHD result code
+ */
+MHD_RESULT
+TMH_private_post_instances (const struct TMH_RequestHandler *rh,
+                            struct MHD_Connection *connection,
+                            struct TMH_HandlerContext *hc)
+{
+  return post_instances (rh,
+                         connection,
+                         hc,
+                         GNUNET_TIME_UNIT_ZERO,
+                         false);
+}
+
+
+/**
+ * Generate an instance, given its configuration.
+ * Public handler to be used when self-provisioning.
+ *
+ * @param rh context of the handler
+ * @param connection the MHD connection to handle
+ * @param[in,out] hc context with further information about the request
+ * @return MHD result code
+ */
+MHD_RESULT
+TMH_public_post_instances (const struct TMH_RequestHandler *rh,
+                           struct MHD_Connection *connection,
+                           struct TMH_HandlerContext *hc)
+{
+  struct GNUNET_TIME_Relative expiration;
+
+  TALER_MHD_parse_request_rel_time (connection,
+                                    "token_validity_ms",
+                                    &expiration);
+  if (GNUNET_YES !=
+      TMH_have_self_provisioning)
+  {
+    GNUNET_break_op (0);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_FORBIDDEN,
+                                       TALER_EC_MERCHANT_GENERIC_UNAUTHORIZED,
+                                       "Self-provisioning is not enabled");
+  }
+
+  return post_instances (rh,
+                         connection,
+                         hc,
+                         expiration,
+                         TEH_TCS_NONE !=
+                         TEH_mandatory_tan_channels);
 }
 
 
