@@ -24,8 +24,9 @@
 #include <microhttpd.h>
 #include "taler-merchant-httpd.h"
 
+
 /**
- * Return our single-page-app user interface (see contrib/spa.html).
+ * Return our single-page-app user interface (see contrib/spa/).
  *
  * @param rh request handler
  * @param connection the connection we act upon
@@ -37,10 +38,13 @@ TMH_return_spa (const struct TMH_RequestHandler *rh,
                 struct MHD_Connection *connection,
                 struct TMH_HandlerContext *hc);
 
+
 /**
- * Preload and compress SPA file.
+ * Preload and compress SPA files.
+ *
+ * @return #GNUNET_OK on success
  */
-int
+enum GNUNET_GenericReturnValue
 TMH_spa_init (void);
 
 
