@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2023 Taler Systems SA
+  Copyright (C) 2023, 2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -379,52 +379,7 @@ credit_cb (
                                        &wtid,
                                        &details->amount,
                                        details->credit_account_uri,
-                                       true /* confirmed */);
-      if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
-      {
-        struct TALER_Amount total;
-        struct TALER_Amount wfee;
-        struct TALER_Amount eamount;
-        struct GNUNET_TIME_Timestamp timestamp;
-        bool have_esig;
-        bool verified;
-
-        qs = db_plugin->lookup_transfer (db_plugin->cls,
-                                         w->instance_id,
-                                         exchange_url,
-                                         &wtid,
-                                         &total,
-                                         &wfee,
-                                         &eamount,
-                                         &timestamp,
-                                         &have_esig,
-                                         &verified);
-        if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
-        {
-          GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                      "Inserting transfer for %s into database failed. Is the credit account %s configured correctly?\n",
-                      w->instance_id,
-                      details->credit_account_uri.full_payto);
-        }
-        if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs)
-        {
-          if (0 !=
-              TALER_amount_cmp (&total,
-                                &details->amount))
-          {
-            GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                        "Inserting transfer for %s into database failed. An entry exists for a different transfer amount (%s)!\n",
-                        w->instance_id,
-                        TALER_amount2s (&total));
-          }
-          else
-          {
-            GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                        "Inserting transfer for %s into database failed. An equivalent entry already exists.\n",
-                        w->instance_id);
-          }
-        }
-      }
+                                       serial_id);
       GNUNET_free (exchange_url);
       if (qs < 0)
       {
