@@ -17,15 +17,15 @@
 -- Everything in one big transaction
 BEGIN;
 
--- This script DROPs all of the tables we create, including the
--- versioning schema!
---
--- Unlike the other SQL files, it SHOULD be updated to reflect the
--- latest requirements for dropping tables.
+-- This script DROPs all of the tables we create.
 
-SELECT _v.unregister_patch('merchant-0001');
-SELECT _v.unregister_patch('merchant-0002');
-SELECT _v.unregister_patch('merchant-0003');
+WITH xpatches AS (
+  SELECT patch_name
+  FROM _v.patches
+  WHERE starts_with(patch_name,'merchant-')
+)
+  SELECT _v.unregister_patch(xpatches.patch_name)
+  FROM xpatches;
 
 
 DROP SCHEMA merchant CASCADE;
