@@ -69,7 +69,7 @@ COMMENT ON COLUMN merchant_token_family_keys.private_key_created_at
   IS 'Specifies when the private key was created. Not terribly useful, mostly for debugging.';
 
 -- Function to replace placeholders in a string with a given value
-CREATE OR REPLACE FUNCTION replace_placeholder(
+CREATE FUNCTION replace_placeholder(
   template TEXT,
   key TEXT,
   value TEXT
@@ -84,8 +84,7 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
--- Trigger function to handle pending webhooks for category changes
-CREATE OR REPLACE FUNCTION handle_category_changes()
+CREATE FUNCTION handle_category_changes()
 RETURNS TRIGGER AS $$
 DECLARE
   my_merchant_serial BIGINT;
@@ -103,7 +102,7 @@ BEGIN
 	     url,
 	     http_method,
 	     body_template
-      FROM merchant_webhook
+      FROM merchant.merchant_webhook
       WHERE event_type = 'category_added'
         AND merchant_serial = my_merchant_serial
     LOOP
@@ -123,7 +122,7 @@ BEGIN
                                            my_merchant_serial::TEXT);
 
       -- Insert into pending webhooks for this webhook
-      INSERT INTO merchant_pending_webhooks
+      INSERT INTO merchant.merchant_pending_webhooks
       (merchant_serial, webhook_serial, url, http_method, body)
       VALUES
       (webhook.merchant_serial,
@@ -145,7 +144,7 @@ BEGIN
 	     url,
 	     http_method,
 	     body_template
-      FROM merchant_webhook
+      FROM merchant.merchant_webhook
       WHERE event_type = 'category_updated'
         AND merchant_serial = my_merchant_serial
     LOOP
@@ -173,7 +172,7 @@ BEGIN
                                                   'escape'));
 
       -- Insert into pending webhooks for this webhook
-      INSERT INTO merchant_pending_webhooks
+      INSERT INTO merchant.merchant_pending_webhooks
       (merchant_serial, webhook_serial, url, http_method, body)
       VALUES
       (webhook.merchant_serial,
@@ -195,7 +194,7 @@ BEGIN
 	     url,
 	     http_method,
 	     body_template
-      FROM merchant_webhook
+      FROM merchant.merchant_webhook
       WHERE event_type = 'category_deleted'
         AND merchant_serial = my_merchant_serial
     LOOP
@@ -212,7 +211,7 @@ BEGIN
                                            OLD.category_name);
 
       -- Insert into pending webhooks for this webhook
-      INSERT INTO merchant_pending_webhooks
+      INSERT INTO merchant.merchant_pending_webhooks
       (merchant_serial, webhook_serial, url, http_method, body)
       VALUES
       (webhook.merchant_serial,
@@ -230,6 +229,10 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+COMMENT ON FUNCTION handle_category_changes
+  IS 'Trigger function to handle pending webhooks for category changes';
+
+
 -- Trigger to invoke the trigger function
 CREATE TRIGGER trigger_category_changes
 AFTER INSERT OR UPDATE OR DELETE
@@ -237,8 +240,7 @@ ON merchant_categories
 FOR EACH ROW
 EXECUTE FUNCTION handle_category_changes();
 
--- Function to handle inventory changes and notify webhooks
-CREATE OR REPLACE FUNCTION handle_inventory_changes()
+CREATE FUNCTION handle_inventory_changes()
   RETURNS TRIGGER AS $$
 DECLARE
   my_merchant_serial BIGINT;
@@ -256,7 +258,7 @@ BEGIN
 	     url,
 	     http_method,
 	     body_template
-      FROM merchant_webhook
+      FROM merchant.merchant_webhook
       WHERE event_type = 'inventory_added'
         AND merchant_serial = my_merchant_serial
       LOOP
@@ -312,7 +314,7 @@ BEGIN
                                              NEW.minimum_age::TEXT);
 
         -- Insert into pending webhooks for this webhook
-        INSERT INTO merchant_pending_webhooks
+        INSERT INTO merchant.merchant_pending_webhooks
         (merchant_serial, webhook_serial, url, http_method, body)
         VALUES
           (webhook.merchant_serial,
@@ -334,7 +336,7 @@ BEGIN
 	     url,
 	     http_method,
 	     body_template
-      FROM merchant_webhook
+      FROM merchant.merchant_webhook
       WHERE event_type = 'inventory_updated'
         AND merchant_serial = my_merchant_serial
       LOOP
@@ -429,7 +431,7 @@ BEGIN
                                              NEW.minimum_age::TEXT);
 
         -- Insert into pending webhooks for this webhook
-        INSERT INTO merchant_pending_webhooks
+        INSERT INTO merchant.merchant_pending_webhooks
         (merchant_serial, webhook_serial, url, http_method, body)
         VALUES
           (webhook.merchant_serial,
@@ -451,7 +453,7 @@ BEGIN
 	     url,
 	     http_method,
 	     body_template
-      FROM merchant_webhook
+      FROM merchant.merchant_webhook
       WHERE event_type = 'inventory_deleted'
         AND merchant_serial = my_merchant_serial
       LOOP
@@ -507,7 +509,7 @@ BEGIN
                                              OLD.minimum_age::TEXT);
 
         -- Insert into pending webhooks for this webhook
-        INSERT INTO merchant_pending_webhooks
+        INSERT INTO merchant.merchant_pending_webhooks
         (merchant_serial, webhook_serial, url, http_method, body)
         VALUES
           (webhook.merchant_serial,
@@ -525,6 +527,10 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+COMMENT ON FUNCTION handle_inventory_changes
+  IS 'Function to handle inventory changes and notify webhooks';
+
+
 -- Trigger to invoke the trigger function
 CREATE TRIGGER trigger_inventory_changes
   AFTER INSERT OR UPDATE OR DELETE
