@@ -29,15 +29,14 @@
 enum GNUNET_DB_QueryStatus
 TMH_PG_insert_account (
   void *cls,
-  const char *id,
   const struct TALER_MERCHANTDB_AccountDetails *account_details)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_string (id),
+    GNUNET_PQ_query_param_string (account_details->instance_id),
     GNUNET_PQ_query_param_auto_from_type (&account_details->h_wire),
     GNUNET_PQ_query_param_auto_from_type (&account_details->salt),
-    GNUNET_PQ_query_param_string (account_details->payto_uri),
+    GNUNET_PQ_query_param_string (account_details->payto_uri.full_payto),
     NULL ==account_details->credit_facade_url
     ? GNUNET_PQ_query_param_null ()
     : GNUNET_PQ_query_param_string (account_details->credit_facade_url),
