@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -31,6 +31,8 @@
  *
  * @param cls closure
  * @param deposit_serial serial number of the deposit
+ * @param h_wire hash of the merchant's account that should receive the deposit
+ * @param exchange_url URL of the exchange that is making the deposit
  * @param dd deposit transfer data from the exchange to store
  * @return transaction status
  */
@@ -38,6 +40,8 @@ enum GNUNET_DB_QueryStatus
 TMH_PG_insert_deposit_to_transfer (
   void *cls,
   uint64_t deposit_serial,
+  const struct TALER_MerchantWireHashP *h_wire,
+  const char *exchange_url,
   const struct TALER_EXCHANGE_DepositData *dd);
 
 
