@@ -32,7 +32,8 @@ TMH_PG_insert_instance (
   const struct TALER_MerchantPublicKeyP *merchant_pub,
   const struct TALER_MerchantPrivateKeyP *merchant_priv,
   const struct TALER_MERCHANTDB_InstanceSettings *is,
-  const struct TALER_MERCHANTDB_InstanceAuthSettings *ias)
+  const struct TALER_MERCHANTDB_InstanceAuthSettings *ias,
+  bool validation_needed)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
@@ -47,6 +48,7 @@ TMH_PG_insert_instance (
     GNUNET_PQ_query_param_relative_time (
       &is->default_wire_transfer_delay),
     GNUNET_PQ_query_param_relative_time (&is->default_pay_delay),
+    GNUNET_PQ_query_param_relative_time (&is->default_refund_delay),
     (NULL == is->website)
     ? GNUNET_PQ_query_param_null ()
     : GNUNET_PQ_query_param_string (is->website),
@@ -56,6 +58,12 @@ TMH_PG_insert_instance (
     (NULL == is->logo)
     ? GNUNET_PQ_query_param_null ()
     : GNUNET_PQ_query_param_string (is->logo),
+    (NULL == is->phone)
+    ? GNUNET_PQ_query_param_null ()
+    : GNUNET_PQ_query_param_string (is->phone),
+    GNUNET_PQ_query_param_bool (is->phone_validated),
+    GNUNET_PQ_query_param_bool (is->email_validated),
+    GNUNET_PQ_query_param_bool (validation_needed),
     GNUNET_PQ_query_param_end
   };
   struct GNUNET_PQ_QueryParam params_priv[] = {
@@ -79,12 +87,17 @@ TMH_PG_insert_instance (
            ",use_stefan"
            ",default_wire_transfer_delay"
            ",default_pay_delay"
+           ",default_refund_delay"
            ",website"
            ",email"
            ",logo"
-           ",user_type)"
+           ",phone_number"
+           ",phone_validated"
+           ",email_validated"
+           ",validation_needed)"
            "VALUES"
-           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, 0)");
+           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14, $15, $16, $17, $18)")
+  ;
   qs = GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                            "insert_instance",
                                            params);
