@@ -34,8 +34,8 @@
  * @param wtid identifier of the wire transfer
  * @param credit_amount how much did we receive
  * @param payto_uri what is the merchant's bank account that received the transfer
- * @param confirmed whether the transfer was confirmed by the merchant or
- *                  was merely claimed by the exchange at this point
+ * @param bank_serial_id unique ID for the wire transfer at the bank,
+ *   0 for "NULL" if none is known due to manual import
  * @return transaction status
  */
 enum GNUNET_DB_QueryStatus
@@ -46,7 +46,7 @@ TMH_PG_insert_transfer (
   const struct TALER_WireTransferIdentifierRawP *wtid,
   const struct TALER_Amount *credit_amount,
   struct TALER_FullPayto payto_uri,
-  bool confirmed);
+  uint64_t bank_serial_id);
 
 
 #endif
