@@ -45,7 +45,7 @@ TMH_PG_lookup_contract_terms3 (
   struct PostgresClosure *pg = cls;
   enum GNUNET_DB_QueryStatus qs;
   struct TALER_ClaimTokenP ct;
-  uint16_t ci;
+  uint16_t ci = 0;
   bool choice_index_null = false;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_string (instance_id),
@@ -105,7 +105,7 @@ TMH_PG_lookup_contract_terms3 (
   if (NULL != claim_token)
     *claim_token = ct;
   if (! choice_index_null)
-    *choice_index = ci;
+    *choice_index = (int16_t) ci;
   else
     *choice_index = -1;
   return qs;
