@@ -306,7 +306,7 @@ TMH_PG_lookup_deposits_by_contract_and_coin (
            "  JOIN merchant_deposits dep"
            "    USING (deposit_confirmation_serial)"
            "  JOIN merchant_exchange_signing_keys msig"
-           "    USING (signkey_serial)"
+           "    ON (mcon.signkey_serial=msig.signkey_serial)"
            "  JOIN merchant_accounts acc"
            "    USING (account_serial)"
            " WHERE h_contract_terms=$2"
