@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -46,6 +46,7 @@ TMH_PG_lookup_product (void *cls,
            "SELECT"
            " mi.description"
            ",mi.description_i18n"
+           ",mi.product_name"
            ",mi.unit"
            ",mi.price"
            ",mi.taxes"
@@ -84,6 +85,7 @@ TMH_PG_lookup_product (void *cls,
   }
   else
   {
+    char *my_name = NULL;
     char *my_description = NULL;
     json_t *my_description_i18n = NULL;
     char *my_unit = NULL;
@@ -96,6 +98,8 @@ TMH_PG_lookup_product (void *cls,
                                     &my_description),
       TALER_PQ_result_spec_json ("description_i18n",
                                  &my_description_i18n),
+      GNUNET_PQ_result_spec_string ("product_name",
+                                    &my_name),
       GNUNET_PQ_result_spec_string ("unit",
                                     &my_unit),
       TALER_PQ_result_spec_amount_with_currency ("price",
@@ -129,6 +133,7 @@ TMH_PG_lookup_product (void *cls,
                                                    "lookup_product",
                                                    params,
                                                    rs);
+    pd->product_name = my_name;
     pd->description = my_description;
     pd->description_i18n = my_description_i18n;
     pd->unit = my_unit;
@@ -137,6 +142,7 @@ TMH_PG_lookup_product (void *cls,
     pd->address = my_address;
     *categories = my_categories;
     /* Clear original pointers to that cleanup_result doesn't squash them */
+    my_name = NULL;
     my_description = NULL;
     my_description_i18n = NULL;
     my_unit = NULL;
