@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022, 2024 Taler Systems SA
+   Copyright (C) 2022, 2024, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -60,6 +60,7 @@ TMH_PG_update_product (void *cls,
     GNUNET_PQ_query_param_array_uint64 (num_cats,
                                         cats,
                                         pg->conn),
+    GNUNET_PQ_query_param_string (pd->product_name),
     GNUNET_PQ_query_param_end
   };
   uint64_t ncat;
@@ -101,7 +102,7 @@ TMH_PG_update_product (void *cls,
            ",out_no_cat AS no_cat"
            ",out_no_instance AS no_instance"
            " FROM merchant_do_update_product"
-           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14);");
+           "($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "update_product",
                                                  params,
