@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2014--2024 Taler Systems SA
+  (C) 2014--2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Lesser General Public License as published by the Free Software
@@ -43,6 +43,7 @@
 #include "pg_insert_login_token.h"
 #include "pg_delete_login_token.h"
 #include "pg_select_login_token.h"
+#include "pg_lookup_login_tokens.h"
 #include "pg_insert_account.h"
 #include "pg_update_account.h"
 #include "pg_lookup_instances.h"
@@ -62,6 +63,11 @@
 #include "pg_lookup_instance_auth.h"
 #include "pg_lookup_otp_devices.h"
 #include "pg_update_transfer_status.h"
+#include "pg_lookup_mfa_challenge.h"
+#include "pg_solve_mfa_challenge.h"
+#include "pg_update_mfa_challenge.h"
+#include "pg_create_mfa_challenge.h"
+#include "pg_finalize_transfer_status.h"
 #include "pg_insert_instance.h"
 #include "pg_account_kyc_set_status.h"
 #include "pg_account_kyc_get_status.h"
@@ -86,8 +92,10 @@
 #include "pg_lookup_order_summary.h"
 #include "pg_lookup_orders.h"
 #include "pg_insert_order.h"
+#include "pg_insert_order_blinded_sigs.h"
 #include "pg_unlock_inventory.h"
 #include "pg_insert_order_lock.h"
+#include "pg_select_order_blinded_sigs.h"
 #include "pg_lookup_contract_terms3.h"
 #include "pg_lookup_contract_terms2.h"
 #include "pg_lookup_contract_terms.h"
@@ -119,13 +127,13 @@
 #include "pg_delete_transfer.h"
 #include "pg_check_transfer_exists.h"
 #include "pg_lookup_account.h"
-#include "pg_lookup_wire_fee.h"
+#include "pg_lookup_expected_transfers.h"
 #include "pg_lookup_deposits_by_contract_and_coin.h"
-#include "pg_lookup_transfer.h"
 #include "pg_lookup_transfer_summary.h"
 #include "pg_lookup_transfer_details.h"
 #include "pg_lookup_webhooks.h"
 #include "pg_lookup_webhook.h"
+#include "pg_lookup_wire_fee.h"
 #include "pg_delete_webhook.h"
 #include "pg_insert_webhook.h"
 #include "pg_update_webhook.h"
@@ -135,7 +143,6 @@
 #include "pg_update_pending_webhook.h"
 #include "pg_lookup_pending_webhooks.h"
 #include "pg_update_deposit_confirmation_status.h"
-#include "pg_set_transfer_status_to_confirmed.h"
 #include "pg_insert_exchange_keys.h"
 #include "pg_select_exchange_keys.h"
 #include "pg_insert_deposit_to_transfer.h"
@@ -155,7 +162,26 @@
 #include "pg_insert_spent_token.h"
 #include "pg_insert_issued_token.h"
 #include "pg_lookup_spent_tokens_by_order.h"
+#include "pg_lookup_statistics_amount_by_bucket.h"
+#include "pg_lookup_statistics_amount_by_interval.h"
+#include "pg_lookup_statistics_counter_by_bucket.h"
+#include "pg_lookup_statistics_counter_by_interval.h"
+#include "pg_update_donau_instance_receipts_amount.h"
+#include "pg_delete_donau_instance.h"
 
+#ifdef HAVE_DONAU_DONAU_SERVICE_H
+#include "donau/donau_service.h"
+#include "pg_insert_donau_instance.h"
+#include "pg_check_donau_instance.h"
+#include "pg_select_donau_instance_by_serial.h"
+#include "pg_select_all_donau_instances.h"
+#include "pg_select_donau_instances.h"
+#include "pg_select_donau_instances_filtered.h"
+#include "pg_lookup_donau_keys.h"
+#include "pg_lookup_order_charity.h"
+#include "pg_upsert_donau_keys.h"
+#include "pg_update_donau_instance.h"
+#endif
 
 /**
  * How often do we re-try if we run into a DB serialization error?
@@ -383,8 +409,12 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_insert_login_token;
   plugin->delete_login_token
     = &TMH_PG_delete_login_token;
+  plugin->delete_login_token_serial
+    = &TMH_PG_delete_login_token_serial;
   plugin->select_login_token
     = &TMH_PG_select_login_token;
+  plugin->lookup_login_tokens
+    = &TMH_PG_lookup_login_tokens;
   plugin->select_account_by_uri
     = &TMH_PG_select_account_by_uri;
   plugin->lookup_instance_auth
@@ -425,6 +455,8 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_inactivate_account;
   plugin->update_transfer_status
     = &TMH_PG_update_transfer_status;
+  plugin->finalize_transfer_status
+    = &TMH_PG_finalize_transfer_status;
   plugin->lookup_products
     = &TMH_PG_lookup_products;
   plugin->lookup_all_products
@@ -461,10 +493,14 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_lookup_orders;
   plugin->insert_order
     = &TMH_PG_insert_order;
+  plugin->insert_order_blinded_sigs
+    = &TMH_PG_insert_order_blinded_sigs;
   plugin->unlock_inventory
     = &TMH_PG_unlock_inventory;
   plugin->insert_order_lock
     = &TMH_PG_insert_order_lock;
+  plugin->select_order_blinded_sigs
+    = &TMH_PG_select_order_blinded_sigs;
   plugin->lookup_contract_terms
     = &TMH_PG_lookup_contract_terms;
   plugin->lookup_contract_terms2
@@ -521,10 +557,6 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_lookup_wire_fee;
   plugin->lookup_deposits_by_contract_and_coin
     = &TMH_PG_lookup_deposits_by_contract_and_coin;
-  plugin->lookup_transfer
-    = &TMH_PG_lookup_transfer;
-  plugin->set_transfer_status_to_confirmed
-    = &TMH_PG_set_transfer_status_to_confirmed;
   plugin->lookup_transfer_summary
     = &TMH_PG_lookup_transfer_summary;
   plugin->lookup_transfer_details
@@ -611,6 +643,8 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_insert_exchange_account;
   plugin->insert_token_family
     = &TMH_PG_insert_token_family;
+  plugin->lookup_expected_transfers
+    = &TMH_PG_lookup_expected_transfers;
   plugin->lookup_token_family
     = &TMH_PG_lookup_token_family;
   plugin->lookup_token_families
@@ -625,15 +659,56 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_lookup_token_family_key;
   plugin->update_deposit_confirmation_status
     = &TMH_PG_update_deposit_confirmation_status;
+  plugin->update_donau_instance_receipts_amount
+    = &TMH_PG_update_donau_instance_receipts_amount;
   plugin->insert_spent_token
     = &TMH_PG_insert_spent_token;
   plugin->insert_issued_token
     = &TMH_PG_insert_issued_token;
   plugin->lookup_spent_tokens_by_order
     = &TMH_PG_lookup_spent_tokens_by_order;
+  plugin->lookup_statistics_amount_by_bucket
+    = &TMH_PG_lookup_statistics_amount_by_bucket;
+  plugin->lookup_statistics_counter_by_bucket
+    = &TMH_PG_lookup_statistics_counter_by_bucket;
+  plugin->lookup_statistics_counter_by_interval
+    = &TMH_PG_lookup_statistics_counter_by_interval;
+  plugin->lookup_statistics_amount_by_interval
+    = &TMH_PG_lookup_statistics_amount_by_interval;
+  plugin->lookup_mfa_challenge
+    = &TMH_PG_lookup_mfa_challenge;
+  plugin->solve_mfa_challenge
+    = &TMH_PG_solve_mfa_challenge;
+  plugin->update_mfa_challenge
+    = &TMH_PG_update_mfa_challenge;
+  plugin->create_mfa_challenge
+    = &TMH_PG_create_mfa_challenge;
   plugin->gc
     = &TMH_PG_gc;
-
+#ifdef HAVE_DONAU_DONAU_SERVICE_H
+  plugin->insert_donau_instance
+    = &TMH_PG_insert_donau_instance;
+  plugin->check_donau_instance
+    = &TMH_PG_check_donau_instance;
+  plugin->select_donau_instance_by_serial
+    = &TMH_PG_select_donau_instance_by_serial;
+  plugin->select_all_donau_instances
+    = &TMH_PG_select_all_donau_instances;
+  plugin->select_donau_instances
+    = &TMH_PG_select_donau_instances;
+  plugin->select_donau_instances_filtered
+    = &TMH_PG_select_donau_instances_filtered;
+  plugin->delete_donau_instance
+    = &TMH_PG_delete_donau_instance;
+  plugin->lookup_donau_keys
+    = &TMH_PG_lookup_donau_keys;
+  plugin->lookup_order_charity
+    = &TMH_PG_lookup_order_charity;
+  plugin->upsert_donau_keys
+    = &TMH_PG_upsert_donau_keys;
+  plugin->update_donau_instance
+    = &TMH_PG_update_donau_instance;
+#endif
   return plugin;
 }
 
