@@ -32,8 +32,9 @@ static const struct
   const char *m;
   enum TALER_MERCHANT_BANK_AuthenticationMethod e;
 } methods[] = {
-  { "NONE",  TALER_MERCHANT_BANK_AUTH_NONE  },
-  { "BASIC", TALER_MERCHANT_BANK_AUTH_BASIC },
+  { "NONE",   TALER_MERCHANT_BANK_AUTH_NONE   },
+  { "BASIC",  TALER_MERCHANT_BANK_AUTH_BASIC  },
+  { "BEARER", TALER_MERCHANT_BANK_AUTH_BEARER },
   { NULL, TALER_MERCHANT_BANK_AUTH_NONE     }
 };
 
@@ -113,6 +114,23 @@ TALER_MERCHANT_BANK_auth_parse_cfg (
         auth->method = TALER_MERCHANT_BANK_AUTH_BASIC;
         GNUNET_free (method);
         return GNUNET_OK;
+      case TALER_MERCHANT_BANK_AUTH_BEARER:
+        if (GNUNET_OK !=
+            GNUNET_CONFIGURATION_get_value_string (cfg,
+                                                   section,
+                                                   "TOKEN",
+                                                   &auth->details.bearer.token))
+        {
+          GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
+                                     section,
+                                     "TOKEN");
+          GNUNET_free (method);
+          GNUNET_free (auth->wire_gateway_url);
+          return GNUNET_SYSERR;
+        }
+        auth->method = TALER_MERCHANT_BANK_AUTH_BEARER;
+        GNUNET_free (method);
+        return GNUNET_OK;
       }
     }
   }
@@ -191,6 +209,35 @@ TALER_MERCHANT_BANK_auth_parse_json (
         }
         auth->method = TALER_MERCHANT_BANK_AUTH_BASIC;
         return GNUNET_OK;
+      case TALER_MERCHANT_BANK_AUTH_BEARER:
+        {
+          const char *token;
+          struct GNUNET_JSON_Specification spec[] = {
+            GNUNET_JSON_spec_string ("token",
+                                     &token),
+            GNUNET_JSON_spec_end ()
+          };
+          enum GNUNET_GenericReturnValue res;
+          const char *err;
+          unsigned int eline;
+
+          res = GNUNET_JSON_parse (cred,
+                                   spec,
+                                   &err,
+                                   &eline);
+          if (GNUNET_OK != res)
+          {
+            GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                        "Credentials malformed: %s (%u)\n",
+                        err,
+                        eline);
+            GNUNET_free (auth->wire_gateway_url);
+            return GNUNET_SYSERR;
+          }
+          auth->details.bearer.token = GNUNET_strdup (token);
+        }
+        auth->method = TALER_MERCHANT_BANK_AUTH_BEARER;
+        return GNUNET_OK;
       }
     }
   }
@@ -210,6 +257,9 @@ TALER_MERCHANT_BANK_auth_free (
     GNUNET_free (auth->details.basic.username);
     GNUNET_free (auth->details.basic.password);
     break;
+  case TALER_MERCHANT_BANK_AUTH_BEARER:
+    GNUNET_free (auth->details.bearer.token);
+    break;
   }
   GNUNET_free (auth->wire_gateway_url);
 }
