@@ -30,6 +30,9 @@
 #include <gnunet/gnunet_time_lib.h>
 #include <taler/taler_testing_lib.h>
 #include "taler_merchant_service.h"
+#ifdef HAVE_DONAU_DONAU_SERVICE_H
+#include "donau/donau_service.h"
+#endif // HAVE_DONAU_DONAU_SERVICE_H
 
 /* ********************* Helper functions ********************* */
 
@@ -121,6 +124,56 @@ TALER_TESTING_cmd_merchant_post_instance_auth (const char *label,
                                                unsigned int http_status);
 
 
+/**
+ * Define a "POST /private/token" CMD.
+ *
+ * @param label command label.
+ * @param merchant_url base URL of the merchant serving the
+ *        POST /instances request.
+ * @param instance_id the ID of the instance, or NULL
+ * @param scope scope to request, can be NULL
+ * @param duration requested token validity duration
+ * @param refreshable should token be refreshable
+ * @param http_status expected HTTP response code.
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_post_instance_token (const char *label,
+                                                const char *merchant_url,
+                                                const char *instance_id,
+                                                const char *scope,
+                                                struct GNUNET_TIME_Relative
+                                                duration,
+                                                bool refreshable,
+                                                unsigned int http_status);
+
+/**
+ * Set the access token gotten through another CMD
+ *
+ * @param label command label.
+ * @param cmd_job_label the other command exposing the bearer_token trait.
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_set_instance_token (const char *label,
+                                               const char *cmd_job_label);
+
+/**
+ * Define a "DELETE /private/token" CMD.
+ *
+ * @param label command label.
+ * @param merchant_url base URL of the merchant serving the
+ *        POST /instances request.
+ * @param instance_id the ID of the instance, or NULL
+ * @param http_status expected HTTP response code.
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_delete_instance_token (const char *label,
+                                                  const char *merchant_url,
+                                                  const char *instance_id,
+                                                  unsigned int http_status);
+
 /**
  * Define a "POST /instances" CMD.  Comprehensive version.
  *
@@ -614,6 +667,8 @@ TALER_TESTING_cmd_merchant_post_orders3 (
  *        the proposal request.
  * @param http_status expected HTTP status.
  * @param token_family_slug slug of the token family to use
+ * @param choice_description description of the choice
+ * @param choice_description_i18n json of description translations
  * @param num_inputs number of input tokens.
  * @param num_outputs number of output tokens.
  * @param order_id the name of the order to add.
@@ -630,6 +685,8 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const char *merchant_url,
   unsigned int http_status,
   const char *token_family_slug,
+  const char *choice_description,
+  json_t *choice_description_i18n,
   unsigned int num_inputs,
   unsigned int num_outputs,
   const char *order_id,
@@ -638,6 +695,32 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const char *amount);
 
 
+/**
+ * Create an order with a choices array with output choice for donau.
+ *
+ * @param label command label
+ * @param cfg configuration to use
+ * @param merchant_url base URL of the merchant serving
+ *        the proposal request.
+ * @param http_status expected HTTP status.
+ * @param order_id the name of the order to add.
+ * @param refund_deadline the deadline for refunds on this order.
+ * @param pay_deadline the deadline for payment on this order.
+ * @param amount the amount this order is for.
+ * @return the command
+ */
+
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_post_orders_donau (
+  const char *label,
+  const struct GNUNET_CONFIGURATION_Handle *cfg,
+  const char *merchant_url,
+  unsigned int http_status,
+  const char *order_id,
+  struct GNUNET_TIME_Timestamp refund_deadline,
+  struct GNUNET_TIME_Timestamp pay_deadline,
+  const char *amount);
+
 /**
  * Define a "GET /orders" CMD.
  *
@@ -1019,6 +1102,47 @@ TALER_TESTING_cmd_merchant_pay_order_choices (
   int choice_index,
   const char *input_reference);
 
+#ifdef HAVE_DONAU_DONAU_SERVICE_H
+
+/**
+ * Make a "pay" test command for an order with choices.
+ *
+ * @param label command label.
+ * @param merchant_url merchant base url
+ * @param http_status expected HTTP response code.
+ * @param proposal_reference the proposal whose payment status
+ *        is going to be checked.
+ * @param coin_reference reference to any command which is able
+ *        to provide coins to use for paying.
+ * @param amount_with_fee amount to pay, including the deposit
+ *        fee
+ * @param amount_without_fee amount to pay, no fees included.
+ * @param amount_donation amount for which the BKPS will be received.
+ * @param session_id the session id to use for the payment (can be NULL).
+ * @param choice_index index of the selected choice for the payment.
+ * @param year year of the donation
+ * @param donor_tax_id tax ID of the donor
+ * @param salt salt for the donation
+ * @return the command
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_pay_order_donau (
+  const char *label,
+  const char *merchant_url,
+  unsigned int http_status,
+  const char *proposal_reference,
+  const char *coin_reference,
+  const char *amount_with_fee,
+  const char *amount_without_fee,
+  const char *amount_donation,
+  const char *session_id,
+  int choice_index,
+  const char *charity_reference,
+  uint64_t year,
+  const char *donor_tax_id,
+  const char *salt);
+
+#endif
 
 /**
  * Make an "order paid" test command.
@@ -1791,6 +1915,128 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
                                 const char *expected_header,
                                 const char *expected_body);
 
+
+#ifdef HAVE_DONAU_DONAU_SERVICE_H
+/**
+ * This function is the similar to the TALER_TESSTING_cmd_charity_post from DONAU
+ * with only difference that it reuses the merchant public key, from the merchant test-suite.
+ *
+ * @param label command label
+ * @param name name of the charity
+ * @param url url of the charity
+ * @param max_per_year maximum amount of donations per year
+ * @param bearer
+ * @param merchant_reference reference to fetch the merchant public key
+ * @param expected_response_code expected HTTP response code
+ * @return
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_charity_post_merchant (
+  const char *label,
+  const char *name,
+  const char *url,
+  const char *max_per_year,
+  const struct DONAU_BearerToken *bearer,
+  const char *merchant_reference,
+  unsigned int expected_response_code);
+
+#endif /* HAVE_DONAU_DONAU_SERVICE_H */
+
+/**
+ * Define a "GET /donau" CMD.
+ *
+ * @param label command label.
+ * @param url base URL of the Donau we are looking for instances of.
+ * @param instance_count number of instances we expect to be returned.
+ * @param expected_http_status expected HTTP response code.
+ * @param ... NULL-terminated list of labels (const char *) of
+ *        donau instances (commands) we expect to be returned in the list
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_get_donau_instances (const char *label,
+                                                const char *url,
+                                                unsigned int instance_count,
+                                                unsigned int
+                                                expected_http_status,
+                                                ...);
+
+
+/**
+ * Define a "POST /donau" CMD.
+ *
+ * @param label command label.
+ * @param url base URL of the Donau service serving the
+ *        GET /donau_instances request.
+ * @param merchant_reference string reference to get the testing traits
+ * @param expected_http_status expected HTTP response code.
+ * @param ... NULL-terminated list of labels (const char *) of
+ *        donau instances (commands) we expect to be returned in the list
+ *        (assuming @a expected_http_status is #MHD_HTTP_OK)
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_post_donau_instance (const char *label,
+                                                const char *url,
+                                                const char *merchant_reference,
+                                                unsigned int
+                                                expected_http_status,
+                                                ...);
+
+
+/**
+ * Define a "DELETE /donau/$charity_id" CMD.
+ *
+ * @param label command label.
+ * @param url base URL of the Donau service serving the
+ *        DELETE /donau/$charity_id request.
+ * @param charity_id the ID of the charity to delete.
+ * @param expected_http_status expected HTTP response code.
+ * @return the command.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_delete_donau_instance (const char *label,
+                                                  const char *url,
+                                                  uint64_t charity_id,
+                                                  unsigned int
+                                                  expected_http_status);
+
+/**
+ * This function is used to check the statistics counter API
+ *
+ * @param label command label
+ * @param merchant_url base URL of the merchant serving the API
+ * @param slug base statistics slug
+ * @param buckets_length expected length of buckets array
+ * @param intervals_length expected length of intervals array
+ * @param http_status expected HTTP response code.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_get_statisticscounter (const char *label,
+                                                  const char *merchant_url,
+                                                  const char *slug,
+                                                  uint64_t buckets_length,
+                                                  uint64_t intervals_length,
+                                                  unsigned int http_status);
+
+/**
+ * This function is used to check the statistics amount API
+ *
+ * @param label command label
+ * @param merchant_url base URL of the merchant serving the API
+ * @param slug base statistics slug
+ * @param buckets_length expected length of buckets array
+ * @param intervals_length expected length of intervals array
+ * @param http_status expected HTTP response code.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_get_statisticsamount (const char *label,
+                                                 const char *merchant_url,
+                                                 const char *slug,
+                                                 uint64_t buckets_length,
+                                                 uint64_t intervals_length,
+                                                 unsigned int http_status);
+
 /* ****** Specific traits supported by this component ******* */
 
 
@@ -1814,6 +2060,7 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
         op (reason, const char) \
         op (lock_uuid, const char) \
         op (auth_token, const char) \
+        op (bearer_token, const char) \
         op (paths_length, const uint32_t) \
         op (payto_length, const uint32_t) \
         op (num_planchets, const uint32_t) \
