@@ -306,7 +306,7 @@ TALER_MERCHANT_orders_get3 (
 
   /* build ogh->url with the various optional arguments */
   {
-    char *dstr;
+    char dstr[30];
     char *fec = NULL;
     char *sid = NULL;
     bool have_date;
@@ -335,7 +335,10 @@ TALER_MERCHANT_orders_get3 (
       (void) GNUNET_STRINGS_urlencode (strlen (fulfillment_url),
                                        fulfillment_url,
                                        &fec);
-    dstr = GNUNET_strdup (GNUNET_TIME_timestamp2s (date));
+    GNUNET_snprintf (dstr,
+                     sizeof (dstr),
+                     "%llu",
+                     (unsigned long long) GNUNET_TIME_timestamp_to_s (date));
     if (delta > 0)
     {
       have_date = ! GNUNET_TIME_absolute_is_zero (date.abs_time);
@@ -381,7 +384,6 @@ TALER_MERCHANT_orders_get3 (
                                "fulfillment_url",
                                fec,
                                NULL);
-    GNUNET_free (dstr);
     GNUNET_free (sid);
     GNUNET_free (fec);
   }
