@@ -33,6 +33,17 @@
 #include <taler/taler_signatures.h>
 
 
+/**
+ * Maximum number of refund details we return.
+ */
+#define MAX_REFUND_DETAILS 1024
+
+/**
+ * Maximum number of wire details we return.
+ */
+#define MAX_WIRE_DETAILS 1024
+
+
 /**
  * @brief A GET /private/orders/$ORDER handle
  */
@@ -191,6 +202,11 @@ handle_paid (struct TALER_MERCHANT_OrderMerchantGetHandle *omgh,
                                   &wire_details),
     GNUNET_JSON_spec_array_const ("refund_details",
                                   &refund_details),
+    /* Only available since **v14** */
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_timestamp ("last_payment",
+                                  &osr->details.ok.details.paid.last_payment),
+      NULL),
     GNUNET_JSON_spec_end ()
   };
 
@@ -210,79 +226,102 @@ handle_paid (struct TALER_MERCHANT_OrderMerchantGetHandle *omgh,
 
   osr->details.ok.details.paid.exchange_hc = (unsigned int) hc32;
   {
-    unsigned int wts_len = json_array_size (wire_details);
-    unsigned int ref_len = json_array_size (refund_details);
-    struct TALER_MERCHANT_WireTransfer wts[GNUNET_NZL (wts_len)];
-    struct TALER_MERCHANT_RefundOrderDetail ref[GNUNET_NZL (ref_len)];
+    unsigned int wts_len = (unsigned int) json_array_size (wire_details);
+    unsigned int ref_len = (unsigned int) json_array_size (refund_details);
 
-    for (unsigned int i = 0; i<wts_len; i++)
+    if ( (json_array_size (wire_details) != (size_t)  wts_len) ||
+         (wts_len > MAX_WIRE_DETAILS) )
     {
-      struct TALER_MERCHANT_WireTransfer *wt = &wts[i];
-      const json_t *w = json_array_get (wire_details,
-                                        i);
-      struct GNUNET_JSON_Specification ispec[] = {
-        TALER_JSON_spec_web_url ("exchange_url",
-                                 &wt->exchange_url),
-        GNUNET_JSON_spec_fixed_auto ("wtid",
-                                     &wt->wtid),
-        GNUNET_JSON_spec_timestamp ("execution_time",
-                                    &wt->execution_time),
-        TALER_JSON_spec_amount_any ("amount",
-                                    &wt->total_amount),
-        GNUNET_JSON_spec_bool ("confirmed",
-                               &wt->confirmed),
-        GNUNET_JSON_spec_end ()
-      };
-
-      if (GNUNET_OK !=
-          GNUNET_JSON_parse (w,
-                             ispec,
-                             NULL, NULL))
-      {
-        GNUNET_break_op (0);
-        osr->hr.http_status = 0;
-        osr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
-        omgh->cb (omgh->cb_cls,
-                  osr);
-        return;
-      }
+      GNUNET_break (0);
+      osr->hr.http_status = 0;
+      osr->hr.ec = TALER_EC_GENERIC_ALLOCATION_FAILURE;
+      omgh->cb (omgh->cb_cls,
+                osr);
+      return;
     }
-
-    for (unsigned int i = 0; i<ref_len; i++)
+    if ( (json_array_size (refund_details) != (size_t)  ref_len) ||
+         (ref_len > MAX_REFUND_DETAILS) )
     {
-      struct TALER_MERCHANT_RefundOrderDetail *ro = &ref[i];
-      const json_t *w = json_array_get (refund_details,
-                                        i);
-      struct GNUNET_JSON_Specification ispec[] = {
-        TALER_JSON_spec_amount_any ("amount",
-                                    &ro->refund_amount),
-        GNUNET_JSON_spec_string ("reason",
-                                 &ro->reason),
-        GNUNET_JSON_spec_timestamp ("timestamp",
-                                    &ro->refund_time),
-        GNUNET_JSON_spec_end ()
-      };
-
-      if (GNUNET_OK !=
-          GNUNET_JSON_parse (w,
-                             ispec,
-                             NULL, NULL))
-      {
-        GNUNET_break_op (0);
-        osr->hr.http_status = 0;
-        osr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
-        omgh->cb (omgh->cb_cls,
-                  osr);
-        return;
-      }
+      GNUNET_break (0);
+      osr->hr.http_status = 0;
+      osr->hr.ec = TALER_EC_GENERIC_ALLOCATION_FAILURE;
+      omgh->cb (omgh->cb_cls,
+                osr);
+      return;
     }
+    {
+      struct TALER_MERCHANT_WireTransfer wts[GNUNET_NZL (wts_len)];
+      struct TALER_MERCHANT_RefundOrderDetail ref[GNUNET_NZL (ref_len)];
 
-    osr->details.ok.details.paid.wts = wts;
-    osr->details.ok.details.paid.wts_len = wts_len;
-    osr->details.ok.details.paid.refunds = ref;
-    osr->details.ok.details.paid.refunds_len = ref_len;
-    omgh->cb (omgh->cb_cls,
-              osr);
+      for (unsigned int i = 0; i<wts_len; i++)
+      {
+        struct TALER_MERCHANT_WireTransfer *wt = &wts[i];
+        const json_t *w = json_array_get (wire_details,
+                                          i);
+        struct GNUNET_JSON_Specification ispec[] = {
+          TALER_JSON_spec_web_url ("exchange_url",
+                                   &wt->exchange_url),
+          GNUNET_JSON_spec_fixed_auto ("wtid",
+                                       &wt->wtid),
+          GNUNET_JSON_spec_timestamp ("execution_time",
+                                      &wt->execution_time),
+          TALER_JSON_spec_amount_any ("amount",
+                                      &wt->total_amount),
+          GNUNET_JSON_spec_bool ("confirmed",
+                                 &wt->confirmed),
+          GNUNET_JSON_spec_end ()
+        };
+
+        if (GNUNET_OK !=
+            GNUNET_JSON_parse (w,
+                               ispec,
+                               NULL, NULL))
+        {
+          GNUNET_break_op (0);
+          osr->hr.http_status = 0;
+          osr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
+          omgh->cb (omgh->cb_cls,
+                    osr);
+          return;
+        }
+      }
+
+      for (unsigned int i = 0; i<ref_len; i++)
+      {
+        struct TALER_MERCHANT_RefundOrderDetail *ro = &ref[i];
+        const json_t *w = json_array_get (refund_details,
+                                          i);
+        struct GNUNET_JSON_Specification ispec[] = {
+          TALER_JSON_spec_amount_any ("amount",
+                                      &ro->refund_amount),
+          GNUNET_JSON_spec_string ("reason",
+                                   &ro->reason),
+          GNUNET_JSON_spec_timestamp ("timestamp",
+                                      &ro->refund_time),
+          GNUNET_JSON_spec_end ()
+        };
+
+        if (GNUNET_OK !=
+            GNUNET_JSON_parse (w,
+                               ispec,
+                               NULL, NULL))
+        {
+          GNUNET_break_op (0);
+          osr->hr.http_status = 0;
+          osr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
+          omgh->cb (omgh->cb_cls,
+                    osr);
+          return;
+        }
+      }
+
+      osr->details.ok.details.paid.wts = wts;
+      osr->details.ok.details.paid.wts_len = wts_len;
+      osr->details.ok.details.paid.refunds = ref;
+      osr->details.ok.details.paid.refunds_len = ref_len;
+      omgh->cb (omgh->cb_cls,
+                osr);
+    }
   }
 }
 
