@@ -164,6 +164,7 @@ TALER_MERCHANT_instance_patch (
   bool use_stefan,
   struct GNUNET_TIME_Relative default_wire_transfer_delay,
   struct GNUNET_TIME_Relative default_pay_delay,
+  struct GNUNET_TIME_Relative default_refund_delay,
   TALER_MERCHANT_InstancePatchCallback cb,
   void *cb_cls)
 {
@@ -182,7 +183,9 @@ TALER_MERCHANT_instance_patch (
     GNUNET_JSON_pack_time_rel ("default_wire_transfer_delay",
                                default_wire_transfer_delay),
     GNUNET_JSON_pack_time_rel ("default_pay_delay",
-                               default_pay_delay));
+                               default_pay_delay),
+    GNUNET_JSON_pack_time_rel ("default_refund_delay",
+                               default_refund_delay));
   iph = GNUNET_new (struct TALER_MERCHANT_InstancePatchHandle);
   iph->ctx = ctx;
   iph->cb = cb;
