@@ -130,7 +130,7 @@ TALER_MERCHANT_instance_auth_post (
   struct GNUNET_CURL_Context *ctx,
   const char *backend_url,
   const char *instance_id,
-  const char *auth_token,
+  const char *auth_password,
   TALER_MERCHANT_InstanceAuthPostCallback cb,
   void *cb_cls)
 {
@@ -167,7 +167,7 @@ TALER_MERCHANT_instance_auth_post (
     GNUNET_free (iaph);
     return NULL;
   }
-  if (NULL == auth_token)
+  if (NULL == auth_password)
   {
     req_obj = GNUNET_JSON_PACK (
       GNUNET_JSON_pack_string ("method",
@@ -175,22 +175,11 @@ TALER_MERCHANT_instance_auth_post (
   }
   else
   {
-    if (0 != strncasecmp (RFC_8959_PREFIX,
-                          auth_token,
-                          strlen (RFC_8959_PREFIX)))
-    {
-      GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Authentication token must start with `%s'\n",
-                  RFC_8959_PREFIX);
-      GNUNET_free (iaph->url);
-      GNUNET_free (iaph);
-      return NULL;
-    }
     req_obj = GNUNET_JSON_PACK (
       GNUNET_JSON_pack_string ("method",
                                "token"),
-      GNUNET_JSON_pack_string ("token",
-                               auth_token));
+      GNUNET_JSON_pack_string ("password",
+                               auth_password));
   }
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Requesting URL '%s'\n",
