@@ -65,3 +65,9 @@ function get_payto_uri() {
     libeufin-bank create-account -u "$1" -p "$2" --name "$1" 2> /dev/null
 }
 
+echo -n "Checking for curl ..."
+curl --version 2> /dev/null > /dev/null || exit_skip " no curl"
+echo " OK"
+echo -n "Checking for jq ..."
+jq --version 2> /dev/null > /dev/null || exit_skip " no jq"
+echo " OK"
