@@ -59,23 +59,6 @@ struct OrdersState
    */
   const char *expected_order_id;
 
-  /**
-   * Reference to a POST /tokenfamilies command. Can be NULL.
-   */
-  const char *token_family_reference;
-
-  /**
-   * How many tokens of the token family created in
-   * @a token_family_reference are required as inputs.
-   */
-  unsigned int num_inputs;
-
-  /**
-   * How many tokens of the token family created in
-   * @a token_family_reference should be issued as outputs.
-   */
-  unsigned int num_outputs;
-
   /**
    * Contract terms obtained from the backend.
    */
@@ -86,11 +69,6 @@ struct OrdersState
    */
   json_t *order_terms;
 
-  /**
-   * Choices array with inputs and outputs for v1 order.
-   */
-  json_t *choices;
-
   /**
    * Contract terms hash code.
    */
@@ -588,46 +566,6 @@ orders_run2 (void *cls,
 }
 
 
-/**
- * Constructs the json for a the choices of an order request.
- *
- * @param input_slug the name of the token family to use for input, can be NULL
- * @param output_slug the name of the token family to use for the output, can be NULL.
- * @param input_count number of token inputs to require
- * @param output_count number of tokens to output
- * @param input_valid_after validity date for the input token.
- * @param output_valid_after validity date for the output token.
- * @param[out] choices where to write the json string.
- */
-static void
-make_choices_json (
-  const char *input_slug,
-  const char *output_slug,
-  uint16_t input_count,
-  uint16_t output_count,
-  struct GNUNET_TIME_Timestamp input_valid_after,
-  struct GNUNET_TIME_Timestamp output_valid_after,
-  json_t **choices)
-{
-  /* FIXME: ugly code should return c, use GNUNET_JSON_PACK() for more type-safety */
-  json_t *c;
-
-  c = json_pack("[{s:o, s:o}]",
-    "inputs", json_pack("[{s:s, s:i, s:s, s:o}]",
-                        "kind", "token",
-                        "count", input_count,
-                        "token_family_slug", input_slug,
-                        "valid_after", GNUNET_JSON_from_timestamp(input_valid_after)),
-    "outputs", json_pack("[{s:s, s:i, s:s, s:o}]",
-                         "kind", "token",
-                         "count", output_count,
-                         "token_family_slug", output_slug,
-                         "valid_after", GNUNET_JSON_from_timestamp(output_valid_after)));
-
-  *choices = c;
-}
-
-
 /**
  * Run a "orders" CMD.
  *
@@ -637,15 +575,14 @@ make_choices_json (
  */
 static void
 orders_run3 (void *cls,
-            const struct TALER_TESTING_Command *cmd,
-            struct TALER_TESTING_Interpreter *is)
+             const struct TALER_TESTING_Command *cmd,
+             struct TALER_TESTING_Interpreter *is)
 {
   struct OrdersState *ps = cls;
   struct GNUNET_TIME_Absolute now;
-  const char *slug;
 
   ps->is = is;
-    now = GNUNET_TIME_absolute_get_monotonic (ps->cfg);
+  now = GNUNET_TIME_absolute_get_monotonic (ps->cfg);
   if (NULL == json_object_get (ps->order_terms,
                                "order_id"))
   {
@@ -661,37 +598,6 @@ orders_run3 (void *cls,
     GNUNET_free (order_id);
   }
 
-  {
-    const struct TALER_TESTING_Command *token_family_cmd;
-    token_family_cmd =
-      TALER_TESTING_interpreter_lookup_command (is,
-                                                ps->token_family_reference);
-    if (NULL == token_family_cmd)
-      TALER_TESTING_FAIL (is);
-    if (GNUNET_OK !=
-      TALER_TESTING_get_trait_token_family_slug (token_family_cmd,
-                                                 &slug))
-      TALER_TESTING_FAIL (is);
-  }
-  make_choices_json (slug, slug,
-                     ps->num_inputs,
-                     ps->num_outputs,
-                     GNUNET_TIME_absolute_to_timestamp (now),
-                     GNUNET_TIME_absolute_to_timestamp (now),
-                     &ps->choices);
-
-  GNUNET_assert (0 ==
-                 json_object_set_new (ps->order_terms,
-                                      "choices",
-                                      ps->choices)
-  );
-  GNUNET_assert (0 ==
-                 json_object_set_new (ps->order_terms,
-                                      "version",
-                                      json_string ("1"))
-  );
-
-
   GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
                               &ps->nonce,
                               sizeof (struct GNUNET_CRYPTO_EddsaPublicKey));
@@ -768,7 +674,7 @@ mark_forgettable (void *cls,
  * @param order_id the name of the order to add, can be NULL.
  * @param refund_deadline the deadline for refunds on this order.
  * @param pay_deadline the deadline for payment on this order.
- * @param amount the amount this order is for.
+ * @param amount the amount this order is for, NULL for v1 orders
  * @param[out] order where to write the json string.
  */
 static void
@@ -784,7 +690,7 @@ make_order_json (const char *order_id,
 
   /* Include required fields and some dummy objects to test forgetting. */
   contract_terms = json_pack (
-    "{s:s, s:s?, s:s, s:s, s:o, s:o, s:s, s:[{s:s}, {s:s}, {s:s}]}",
+    "{s:s, s:s?, s:s?, s:s, s:o, s:o, s:s, s:[{s:s}, {s:s}, {s:s}]}",
     "summary", "merchant-lib testcase",
     "order_id", order_id,
     "amount", amount,
@@ -979,7 +885,9 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const struct GNUNET_CONFIGURATION_Handle *cfg,
   const char *merchant_url,
   unsigned int http_status,
-  const char *token_family_reference,
+  const char *token_family_slug,
+  const char *choice_description,
+  json_t *choice_description_i18n,
   unsigned int num_inputs,
   unsigned int num_outputs,
   const char *order_id,
@@ -988,18 +896,160 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const char *amount)
 {
   struct OrdersState *ps;
+  struct TALER_Amount brutto;
+  json_t *choice;
+  json_t *choices;
+  json_t *inputs;
+  json_t *outputs;
 
   ps = GNUNET_new (struct OrdersState);
   ps->cfg = cfg;
   make_order_json (order_id,
                    refund_deadline,
                    pay_deadline,
-                   amount,
+                   NULL,
                    &ps->order_terms);
+  GNUNET_assert (GNUNET_OK ==
+                 TALER_string_to_amount (amount,
+                                         &brutto));
+  inputs = json_array ();
+  GNUNET_assert (NULL != inputs);
+  GNUNET_assert (0 ==
+                 json_array_append_new (
+                   inputs,
+                   GNUNET_JSON_PACK (
+                     GNUNET_JSON_pack_string ("type",
+                                              "token"),
+                     GNUNET_JSON_pack_uint64 ("count",
+                                              num_inputs),
+                     GNUNET_JSON_pack_string ("token_family_slug",
+                                              token_family_slug)
+                     )));
+  outputs = json_array ();
+  GNUNET_assert (NULL != outputs);
+  GNUNET_assert (0 ==
+                 json_array_append_new (
+                   outputs,
+                   GNUNET_JSON_PACK (
+                     GNUNET_JSON_pack_string ("type",
+                                              "token"),
+                     GNUNET_JSON_pack_uint64 ("count",
+                                              num_outputs),
+                     GNUNET_JSON_pack_string ("token_family_slug",
+                                              token_family_slug)
+                     )));
+  choice
+    = GNUNET_JSON_PACK (
+        TALER_JSON_pack_amount ("amount",
+                                &brutto),
+        GNUNET_JSON_pack_allow_null (
+          GNUNET_JSON_pack_string ("description",
+                                   choice_description)),
+        GNUNET_JSON_pack_allow_null (
+          GNUNET_JSON_pack_object_steal ("description_i18n",
+                                         choice_description_i18n)),
+        GNUNET_JSON_pack_array_steal ("inputs",
+                                      inputs),
+        GNUNET_JSON_pack_array_steal ("outputs",
+                                      outputs));
+  choices = json_array ();
+  GNUNET_assert (NULL != choices);
+  GNUNET_assert (0 ==
+                 json_array_append_new (
+                   choices,
+                   choice));
+  GNUNET_assert (0 ==
+                 json_object_set_new (ps->order_terms,
+                                      "choices",
+                                      choices)
+                 );
+  GNUNET_assert (0 ==
+                 json_object_set_new (ps->order_terms,
+                                      "version",
+                                      json_integer (1))
+                 );
+
+
+  ps->http_status = http_status;
+  ps->expected_order_id = order_id;
+  ps->merchant_url = merchant_url;
+  ps->with_claim = true;
+  {
+    struct TALER_TESTING_Command cmd = {
+      .cls = ps,
+      .label = label,
+      .run = &orders_run3,
+      .cleanup = &orders_cleanup,
+      .traits = &orders_traits
+    };
+
+    return cmd;
+  }
+}
+
+
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_post_orders_donau (
+  const char *label,
+  const struct GNUNET_CONFIGURATION_Handle *cfg,
+  const char *merchant_url,
+  unsigned int http_status,
+  const char *order_id,
+  struct GNUNET_TIME_Timestamp refund_deadline,
+  struct GNUNET_TIME_Timestamp pay_deadline,
+  const char *amount)
+{
+  struct OrdersState *ps;
+  struct TALER_Amount brutto;
+  json_t *choice;
+  json_t *choices;
+  json_t *outputs;
+
+  ps = GNUNET_new (struct OrdersState);
+  ps->cfg = cfg;
+  make_order_json (order_id,
+                   refund_deadline,
+                   pay_deadline,
+                   NULL,
+                   &ps->order_terms);
+  GNUNET_assert (GNUNET_OK ==
+                 TALER_string_to_amount (amount,
+                                         &brutto));
+
+  outputs = json_array ();
+  GNUNET_assert (NULL != outputs);
+  GNUNET_assert (0 ==
+                 json_array_append_new (
+                   outputs,
+                   GNUNET_JSON_PACK (
+                     GNUNET_JSON_pack_string ("type",
+                                              "tax-receipt")
+                     )));
+  choice
+    = GNUNET_JSON_PACK (
+        TALER_JSON_pack_amount ("amount",
+                                &brutto),
+        GNUNET_JSON_pack_array_steal ("outputs",
+                                      outputs));
+  choices = json_array ();
+  GNUNET_assert (NULL != choices);
+  GNUNET_assert (0 ==
+                 json_array_append_new (
+                   choices,
+                   choice));
+  GNUNET_assert (0 ==
+                 json_object_set_new (ps->order_terms,
+                                      "choices",
+                                      choices)
+                 );
+  GNUNET_assert (0 ==
+                 json_object_set_new (ps->order_terms,
+                                      "version",
+                                      json_integer (1))
+                 );
+
+
   ps->http_status = http_status;
-  ps->token_family_reference = token_family_reference;
-  ps->num_inputs = num_inputs;
-  ps->num_outputs = num_outputs;
   ps->expected_order_id = order_id;
   ps->merchant_url = merchant_url;
   ps->with_claim = true;
