@@ -69,7 +69,8 @@ tme_run (void *cls,
                                "taler-merchant-reconciliation",
                                "-c", ws->config_filename,
                                "-t", /* exit when done */
-                               "-L", "DEBUG",
+                               "-T", "1200s",
+                               "-L", "INFO",
                                NULL);
   if (NULL == ws->merchant_reconciliation_proc)
   {
