@@ -58,6 +58,18 @@ struct WalletGetOrderState
    */
   const char *order_reference;
 
+  /**
+   * Reference to a command that created a paid
+   * equivalent order that we expect to be referred
+   * to during repurchase detection, or NULL.
+   */
+  const char *repurchase_order_ref;
+
+  /**
+   * Session Id the order needs to be bound to.
+   */
+  const char *session_id;
+
   /**
    * Whether the order was paid or not.
    */
@@ -125,6 +137,31 @@ wallet_get_order_cb (
       const char *order_id;
       const struct TALER_ClaimTokenP *claim_token;
 
+      if (NULL != gos->repurchase_order_ref)
+      {
+        const struct TALER_TESTING_Command *rep_cmd;
+        const char *rep_id;
+        const char *ri;
+
+        rep_cmd = TALER_TESTING_interpreter_lookup_command (
+          gos->is,
+          gos->repurchase_order_ref);
+        if (GNUNET_OK !=
+            TALER_TESTING_get_trait_order_id (rep_cmd,
+                                              &rep_id))
+        {
+          TALER_TESTING_FAIL (gos->is);
+        }
+        ri = owgr->details.payment_required.already_paid_order_id;
+        if ( (NULL == ri) ||
+             (0 !=
+              strcmp (ri,
+                      rep_id)) )
+        {
+          TALER_TESTING_FAIL (gos->is);
+        }
+      }
+
       if (GNUNET_OK !=
           TALER_MERCHANT_parse_pay_uri (
             owgr->details.payment_required.taler_pay_uri,
@@ -243,7 +280,7 @@ wallet_get_order_run (void *cls,
     order_id,
     h_contract,
     GNUNET_TIME_UNIT_ZERO,
-    NULL,
+    gos->session_id,
     NULL,
     false,
     &wallet_get_order_cb,
@@ -274,13 +311,14 @@ wallet_get_order_cleanup (void *cls,
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_wallet_get_order (const char *label,
-                                    const char *merchant_url,
-                                    const char *order_reference,
-                                    bool paid,
-                                    bool refunded,
-                                    bool refund_pending,
-                                    unsigned int http_status)
+TALER_TESTING_cmd_wallet_get_order (
+  const char *label,
+  const char *merchant_url,
+  const char *order_reference,
+  bool paid,
+  bool refunded,
+  bool refund_pending,
+  unsigned int http_status)
 {
   struct WalletGetOrderState *gos;
 
@@ -304,6 +342,42 @@ TALER_TESTING_cmd_wallet_get_order (const char *label,
 }
 
 
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_wallet_get_order2 (
+  const char *label,
+  const char *merchant_url,
+  const char *order_reference,
+  const char *session_id,
+  bool paid,
+  bool refunded,
+  bool refund_pending,
+  const char *repurchase_order_ref,
+  unsigned int http_status)
+{
+  struct WalletGetOrderState *gos;
+
+  gos = GNUNET_new (struct WalletGetOrderState);
+  gos->merchant_url = merchant_url;
+  gos->order_reference = order_reference;
+  gos->http_status = http_status;
+  gos->paid = paid;
+  gos->session_id = session_id;
+  gos->refunded = refunded;
+  gos->refund_pending = refund_pending;
+  gos->repurchase_order_ref = repurchase_order_ref;
+  {
+    struct TALER_TESTING_Command cmd = {
+      .cls = gos,
+      .label = label,
+      .run = &wallet_get_order_run,
+      .cleanup = &wallet_get_order_cleanup
+    };
+
+    return cmd;
+  }
+}
+
+
 struct WalletPollOrderConcludeState
 {
   /**
