@@ -34,7 +34,7 @@
  *
  * @param cls closure, unused parameter
  * @param root the JSON object representing data
- * @param[out] spec where to write the data
+ * @param[out] ospec where to write the data
  * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
  */
 static enum GNUNET_GenericReturnValue
@@ -323,9 +323,8 @@ TALER_MERCHANT_parse_choice_output (
           GNUNET_break_op (0);
           return GNUNET_SYSERR;
         }
-
         output->details.donation_receipt.donau_urls[i] =
-          json_string_value (jurl);
+          GNUNET_strdup (json_string_value (jurl));
       }
 
       return GNUNET_OK;
@@ -346,7 +345,6 @@ TALER_MERCHANT_parse_choice_output (
  * @param cls closure, pointer to array length
  * @param root the json array representing the choices
  * @param[out] ospec where to write the data
-
  * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
  */
 static enum GNUNET_GenericReturnValue
@@ -373,10 +371,17 @@ parse_choices (
     struct TALER_MERCHANT_ContractChoice *choice = &(*choices)[i];
     const json_t *jinputs;
     const json_t *joutputs;
-
     struct GNUNET_JSON_Specification spec[] = {
       TALER_JSON_spec_amount_any ("amount",
                                   &choice->amount),
+      GNUNET_JSON_spec_mark_optional (
+        GNUNET_JSON_spec_string_copy ("description",
+                                      &choice->description),
+        NULL),
+      GNUNET_JSON_spec_mark_optional (
+        GNUNET_JSON_spec_object_copy ("description_i18n",
+                                      &choice->description_i18n),
+        NULL),
       TALER_JSON_spec_amount_any ("max_fee",
                                   &choice->max_fee),
       GNUNET_JSON_spec_array_const ("inputs",
@@ -385,7 +390,6 @@ parse_choices (
                                     &joutputs),
       GNUNET_JSON_spec_end ()
     };
-
     const char *ename;
     unsigned int eline;
 
@@ -407,6 +411,7 @@ parse_choices (
     {
       const json_t *jinput;
       size_t idx;
+
       json_array_foreach ((json_t *) jinputs, idx, jinput)
       {
         struct TALER_MERCHANT_ContractInput input = {
@@ -418,8 +423,10 @@ parse_choices (
                                                &input,
                                                idx,
                                                false))
+        {
+          GNUNET_break (0);
           return GNUNET_SYSERR;
-
+        }
         switch (input.type)
         {
         case TALER_MERCHANT_CONTRACT_INPUT_TYPE_INVALID:
@@ -431,7 +438,6 @@ parse_choices (
             continue;
           break;
         }
-
         GNUNET_array_append (choice->inputs,
                              choice->inputs_len,
                              input);
@@ -452,8 +458,10 @@ parse_choices (
                                                 &output,
                                                 idx,
                                                 false))
+        {
+          GNUNET_break (0);
           return GNUNET_SYSERR;
-
+        }
         switch (output.type)
         {
         case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_INVALID:
@@ -467,7 +475,6 @@ parse_choices (
         case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_DONATION_RECEIPT:
           break;
         }
-
         GNUNET_array_append (choice->outputs,
                              choice->outputs_len,
                              output);
@@ -504,21 +511,42 @@ spec_choices (
 }
 
 
-/**
- * Free all the fields in the given @a choice, but not @a choice itself, since
- * it is normally part of an array.
- *
- * @param[in] choice contract terms choice to free
- */
-static void
-contract_choice_free (
+void
+TALER_MERCHANT_contract_choice_free (
   struct TALER_MERCHANT_ContractChoice *choice)
 {
   for (unsigned int i = 0; i < choice->outputs_len; i++)
   {
     struct TALER_MERCHANT_ContractOutput *output = &choice->outputs[i];
 
-    GNUNET_free (output->details.coin.exchange_url);
+    switch (output->type)
+    {
+    case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_INVALID:
+      GNUNET_break (0);
+      break;
+    case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_TOKEN:
+      break;
+    case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_DONATION_RECEIPT:
+      for (unsigned int j = 0;
+           j<output->details.donation_receipt.donau_urls_len;
+           j++)
+        GNUNET_free (output->details.donation_receipt.donau_urls[j]);
+      GNUNET_array_grow (output->details.donation_receipt.donau_urls,
+                         output->details.donation_receipt.donau_urls_len,
+                         0);
+      break;
+#if FUTURE
+    case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_COIN:
+      GNUNET_free (output->details.coin.exchange_url);
+      break;
+#endif
+    }
+  }
+  GNUNET_free (choice->description);
+  if (NULL != choice->description_i18n)
+  {
+    json_decref (choice->description_i18n);
+    choice->description_i18n = NULL;
   }
   GNUNET_free (choice->inputs);
   GNUNET_free (choice->outputs);
@@ -531,7 +559,7 @@ contract_choice_free (
  * @param cls closure, unused parameter
  * @param root the JSON object representing data
  * @param[out] ospec where to write the data
- * @return #GNUNET_OK upon successful parsing; @GNUNET_SYSERR upon error
+ * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
  */
 static enum GNUNET_GenericReturnValue
 parse_token_details (void *cls,
@@ -679,7 +707,7 @@ parse_token_details (void *cls,
  * in the contract token family. All fields from @a family are copied.
  *
  * @param name name of the token details field in the JSON
- * @param[out] token family where the token details have to be written
+ * @param[out] family token_family where the token details have to be written
  */
 static struct GNUNET_JSON_Specification
 spec_token_details (const char *name,
@@ -1046,13 +1074,14 @@ parse_contract_v1 (
   struct TALER_MERCHANT_Contract *contract)
 {
   struct GNUNET_JSON_Specification espec[] = {
-    spec_choices ("choices",
-                  &contract->details.v1.choices,
-                  &contract->details.v1.choices_len),
-    spec_token_families ("token_families",
-                         &contract->details.v1.token_authorities,
-                         &contract->details.v1.
-                         token_authorities_len),
+    spec_choices (
+      "choices",
+      &contract->details.v1.choices,
+      &contract->details.v1.choices_len),
+    spec_token_families (
+      "token_families",
+      &contract->details.v1.token_authorities,
+      &contract->details.v1.token_authorities_len),
     GNUNET_JSON_spec_end ()
   };
 
@@ -1064,7 +1093,6 @@ parse_contract_v1 (
                            espec,
                            &ename,
                            &eline);
-
   if (GNUNET_OK != res)
   {
     GNUNET_break (0);
@@ -1271,7 +1299,7 @@ TALER_MERCHANT_contract_free (
     for (unsigned int i = 0;
          i < contract->details.v1.choices_len;
          i++)
-      contract_choice_free (&contract->details.v1.choices[i]);
+      TALER_MERCHANT_contract_choice_free (&contract->details.v1.choices[i]);
     GNUNET_free (contract->details.v1.choices);
     for (unsigned int i = 0;
          i < contract->details.v1.token_authorities_len;
